@@ -5,7 +5,7 @@ import configparser
 class ConfCommand(Command):
     """
     Config the CLI to ready to use
-    config
+    blc:config
     """
 
     def handle(self):
